@@ -369,6 +369,7 @@ class API(object):
             organisms (str, 非必填): 样品生物体,取值范围: 1-3;
             data_availability (boolean, 非必填): 数据可用性;
             statuses (str, 非必填): 数据状态,详情见 BGE 开放平台文档;
+            require_files(boolean, 非必填）: 要求返回关联文件列表
             next_page (int, 非必填): 要获取的页码,默认值为 None;
             limit (int, 非必填): 每页返回数量,默认值为 50;
 
@@ -972,6 +973,43 @@ class API(object):
             '/stream/range', params=params, timeout=timeout)
         return models.Model(result)
 
+    def write_phenotype(self, biosample_id, data_element_id,
+                        stream_generate_time, stream_data,
+                        duplicate_enabled=None, **kwargs):
+        """根据生物套件编号写入表型数据
+
+        Args:
+            biosample_id (str): 生物样品编号;
+            data_element_id (str): 数据元编号;
+            stream_generate_time (datetime): 数据流生成时间，
+                                             如：2021-03-02T10:00:00Z;
+            stream_data(dict): 数据流数据；
+            duplicate_enabled(boolean, 非必填): 允许重复写入；
+
+        Returns:
+            Model: 返回的表型数据流编号数据;
+        """
+        biosample_id = biosample_id.upper()
+        stream_data = json.dumps(stream_data)
+        data = dict()
+        data.update(kwargs)
+        data.update({
+            'biosample_id': biosample_id,
+            'data_element_id': data_element_id,
+            'stream_generate_time': stream_generate_time,
+            'stream_data': stream_data,
+            'duplicate_enabled': duplicate_enabled,
+        })
+        timeout = self.timeout
+        verbose = self.verbose
+        max_retries = self.max_retries
+        request = HTTPRequest(
+            self.endpoint, max_retries=max_retries, verbose=verbose)
+        request.set_authorization(self.token_type, self.access_token)
+        result = request.post(
+            '/datamall/phenotype/write', data=data, timeout=timeout)
+        return models.Model(result)
+
     def get_data_items(self, namespace, biosample_id,
                        collection_id=None, data_element_ids=None,
                        next_page=None, **kwargs):
@@ -1064,15 +1102,18 @@ class API(object):
         return models.Model(result)
 
     def deploy_model(self, model_id, object_name=None, runtime=None,
-                     memory_size=None, timeout=None, **kwargs):
+                     memory_size=None, cpu=None, disk_size=None,
+                     timeout=None, **kwargs):
         """部署模型
 
         Args:
             model_id (str): 模型编号。
             object_name (str): 模型源代码文件阿里云 OSS 对象路径。
-            runtime (str, optional): 运行环境版本。默认值: python3。
-            memory_size (int, optional): 内存占用量,单位: MB。默认: 128MB。
-            timeout (int, 非必填): 模型运行超时时间,单位: 秒。默认: 900。
+            runtime (str, 非必填): 运行环境版本。默认值: python3。
+            memory_size (int, 非必填): 内存占用量,单位: MB。默认: 128MB。
+            cpu(float, 非必填): vCPU 核心数。默认：0.05。
+            disk_size(int, 非必填): 函数计算磁盘规格，单位：MB。默认：512。
+            timeout (int, 非必填): 模型运行超时时间，单位: 秒。默认: 900。
 
         Returns:
             Model: 任务id,时间和状态;
@@ -1083,6 +1124,8 @@ class API(object):
             'model_id': model_id,
             'runtime': runtime,
             'memory_size': memory_size,
+            'cpu': cpu,
+            'disk_size': disk_size,
             'timeout': timeout,
             'object_name': object_name
         })
@@ -1289,3 +1332,39 @@ class API(object):
         result = request.post(
             '/model/doc_upload', data=doc, timeout=timeout)
         return models.Model(result)
+
+    def send_sms(self, template, mobiles, **kwargs):
+        """发送短信
+
+        Args:
+            template (str): 短信模板;
+            mobiles (str): 手机号，多个手机号用逗号分割;
+
+        template：pay_code（积分消费通知短信）
+            pay_code(str): 消费验证码；
+
+        template: research_download_notice（科研数据下载提示短信）
+            org_name(str): 机构名称；
+            project_name(str): 科研调查标题名称；
+            applied_date(str): 申请数据日期；
+            expiry_date(str): 数据有效期日期；
+
+        template: microarray_delivery（芯片版发报告提示短信）
+            user_nick_name(str): 用户昵称；
+
+        Returns:
+            Model: 返回的表型数据流编号数据;
+        """
+        data = dict()
+        data.update(kwargs)
+        data.update({
+            'template': template,
+            'mobiles': mobiles,
+        })
+        timeout = self.timeout
+        verbose = self.verbose
+        max_retries = self.max_retries
+        request = HTTPRequest(
+            self.endpoint, max_retries=max_retries, verbose=verbose)
+        request.set_authorization(self.token_type, self.access_token)
+        request.post('/sms/send', data=data, timeout=timeout)
