@@ -131,13 +131,14 @@ def get_config_parser(path):
     return config_parser
 
 
-def output_json(data, cls=None):
+def output_json(data, indent=4, sort_keys=True, ensure_ascii=False,
+                cls=None):
     syntax = Syntax(
         json.dumps(
             data,
-            indent=4,
-            sort_keys=True,
-            ensure_ascii=False,
+            indent=indent,
+            sort_keys=sort_keys,
+            ensure_ascii=ensure_ascii,
             cls=cls
         ),
         lexer='JSON',
@@ -201,3 +202,14 @@ def get_sys_user():
         gid = pwd_info.pw_gid
         user = '{}:{}'.format(uid, gid)
     return user
+
+
+def generate_next_path(path_pattern):
+    i = 1
+    while os.path.exists(path_pattern % i):
+        i = i * 2
+    a, b = (i // 2, i)
+    while a + 1 < b:
+        c = (a + b) // 2
+        a, b = (c, b) if os.path.exists(path_pattern % c) else (a, c)
+    return path_pattern % b
